@@ -6,14 +6,16 @@ class InRow(BaseStep):
     """
     Only output a prediction when N predictions in a row agree
     """
-    def __init__(self, n, name='InRow'):
+    def __init__(self, n, unkown_class=None, name='InRow'):
         """
         :param n: int number of predictions to agree
+        :param unkown_class: int|None if int, this step will also output "uncertain" class
         """
         assert n <= 255, 'n MUST be <= 255'
 
         super().__init__(name)
         self.n = n
+        self.unknown_class = unkown_class
 
     def fit(self, X, y):
         """
@@ -28,7 +30,9 @@ class InRow(BaseStep):
 
     def transform(self, X, y=None, holes=False):
         """
-        :param fill: if True, appends None to result when not in row
+        :param X: np.ndarray
+        :param y: np.ndarray
+        :param holes: if True, appends np.nan to result when not in row
         """
         count = 0
         current = -1
@@ -45,9 +49,12 @@ class InRow(BaseStep):
             if count >= self.n:
                 Xt.append(xi)
                 yt.append(yi)
+            elif self.unknown_class:
+                Xt.append(self.unknown_class)
+                yt.append(yi)
             elif holes:
                 Xt.append(np.nan)
-                yt.append(np.nan)
+                yt.append(yi)
 
         return np.asarray(Xt), np.asarray(yt) if y is not None else None
 
@@ -58,3 +65,11 @@ class InRow(BaseStep):
         return {
             'n': self.n
         }
+
+    def get_template_data(self):
+        """
+
+        """
+        return {
+            'n': self.n
+        }
